#
# product.py: product identification string
#
# Copyright (C) 2003  Red Hat, Inc.  All rights reserved.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import configparser
import os
import re

from pyanaconda.core.i18n import _

# First, load in the defaults.  In order of precedence:  contents of
# .buildstamp, environment, stupid last ditch hardcoded defaults.
config = configparser.ConfigParser()
config.add_section("Main")
config.set("Main", "Arch", os.environ.get("ANACONDA_PRODUCTARCH", os.uname()[4]))
config.set("Main", "BugURL", os.environ.get("ANACONDA_BUGURL", "your distribution provided bug reporting tool"))
config.set("Main", "IsFinal", os.environ.get("ANACONDA_ISFINAL", "false"))
config.set("Main", "Product", os.environ.get("ANACONDA_PRODUCTNAME", "anaconda"))
config.set("Main", "Variant", os.environ.get("ANACONDA_PRODUCTVARIANT", ""))
config.set("Main", "UUID", "")
config.set("Main", "Version", os.environ.get("ANACONDA_PRODUCTVERSION", "bluesky"))

# Now read in the .buildstamp file, wherever it may be.
config.read(["/.buildstamp", "/tmp/product/.buildstamp", os.environ.get("PRODBUILDPATH", "")])

# Set up some variables we import throughout, applying a couple transforms as necessary.
bugUrl = config.get("Main", "BugURL")
isFinal = config.getboolean("Main", "IsFinal")
productArch = config.get("Main", "Arch")
productName = config.get("Main", "Product")
productVariant = config.get("Main", "Variant")
productStamp = config.get("Main", "UUID")
productVersion = config.get("Main", "Version")

if not productArch and productStamp.index(".") != -1:           # pylint: disable=no-member
    productArch = productStamp[productStamp.index(".") + 1:]      # pylint: disable=no-member
if productVersion == "development":
    productVersion = "rawhide"


def trim_product_version_for_ui(version):
    """Trim off parts of version that should not be displayed in UI.

    Example: 8.0.1 -> 8.0
    """
    if version.count('.') >= 2:
        version = '.'.join(version.split('.')[:2])
    return version


productVersion = trim_product_version_for_ui(productVersion)

if productName.startswith("MSVSphere"):
    productBase = "MSVSphere"
    if productName == "MSVSphere Server" or \
            (productName == "MSVSphere" and productVariant == "Minimal"):
        productFlavor = "Server"
    elif productName == "MSVSphere" and productVariant == "BaseOS":
        productFlavor = "OS"
    elif productName == "MSVSphere":
        os_release = open("/etc/os-release", "r")
        for line in os_release:
            match = re.match("VERSION=.*\((.*?)\)", line)
            if match:
                productFlavor = match.group(1)
    else:
        productFlavor = "OS"
else:
    productBase = productName
    productFlavor = None

def distributionText():
    if productBase == "MSVSphere" and productFlavor == "Server":
        distro_text = _("MSVSphere %(productVersion)s Server INSTALLATION")
    elif productBase == "MSVSphere" and productFlavor == "ARM":
        distro_text = _("MSVSphere %(productVersion)s ARM INSTALLATION")
    elif productBase == "MSVSphere" and productFlavor == "Cinnamon":
        distro_text = _("MSVSphere %(productVersion)s Cinnamon INSTALLATION")
    elif productBase == "MSVSphere" and productFlavor == "KDE":
        distro_text = _("MSVSphere %(productVersion)s KDE INSTALLATION")
    elif productBase == "MSVSphere" and productFlavor == "XFCE":
        distro_text = _("MSVSphere %(productVersion)s XFCE INSTALLATION")
    elif productBase == "MSVSphere" and productFlavor == "OS":
        distro_text = _("MSVSphere %(productVersion)s OS INSTALLATION")
    else:
        distro_text = _("%(productName)s %(productVersion)s INSTALLATION")
    return distro_text % {
             "productName": productName,
             "productVersion": productVersion
    }
